/*
FILE: PS2Storage.h
DESCRIPTION: Header file for the PS2MemoryCard, PS2HardDrive, and PS2StorageManager classes
WRITTEN BY: Derek Nedelman (nedelman@netzero.net)
DATE: August 24, 2002
*/

#ifndef PS2STORAGE_INCLUDED
#define PS2STORAGE_INCLUDED


//Includes---------------------------------------------------------------------
extern "C"
{
#include "memcardlib.h"
};


//Classes----------------------------------------------------------------------
class PS2MemoryCard
{
	friend class PS2StorageManager;

	int index;
	
	void* file;	

public:
	PS2MemoryCard()		{file = 0;}

	int GetIndex() const	{return index;}
	int GetType() const;
	void GetBlockInfo(int* blockSize, int* totalBlocks, int* freeBlocks) const;
	int GetFreeBytes() const;
	int GetTotalBytes() const;
	bool IsFormatted() const;
	int GetStatus() const;

	bool Open(const char* name, int readOrWrite);
	void Close();
	int Read(void* data, int numBytes);
	int Write(const void* data, int numBytes);
	int GetPos() const;
	bool IsOpen() const	{return file != 0;}

	bool FileExists(const char* name) const;
	void DeleteFile(const char* name) const;
};

class PS2HardDrive
{
public:
	void GetBlockInfo(int* blockSize, int* totalBlocks, int* freeBlocks) const;
	bool IsFormatted() const;

	void* Open(const char* name, int readOrWrite);
	void Close(void* file);
	int Read(void* file, void* data, int numBytes);
	int Write(void* file, const void* data, int numBytes);
	int GetPos(void* file) const;

	bool FileExists(const char* name) const;
	void DeleteFile(const char* name) const;
};

class PS2StorageManager
{
	enum {MAX_MEMCARDS = 2};

	static int numMemoryCards;
	static PS2MemoryCard memoryCards[MAX_MEMCARDS];

	static PS2HardDrive hardDrive;

	static bool isInitialized;

public:
	static void Initialize();
	static void Shutdown();

	static int GetNumMemoryCards() 			{return numMemoryCards;}
	static PS2MemoryCard* GetMemoryCard(int card)	{return &memoryCards[card];}

	static bool IsHardDrivePresent();
	static PS2HardDrive* GetHardDrive();
};


#endif
